#version 120

// More realistic depth-of-field by Azraeil.
// This is a modification of Daxnitro's depth-of-field shader.

// If you want a higher quality blur, remove the forward slashes from the following line:
//#define USE_HIGH_QUALITY_BLUR

uniform sampler2D gcolor;
uniform sampler2D gdepth;
uniform sampler2D composite;

varying vec4 texcoord;

uniform float aspectRatio;
uniform float near;
uniform float far;

// HYPERFOCAL = (Focal Distance ^ 2)/(Circle of Confusion * F Stop) + Focal Distance
const float HYPERFOCAL = 3.132;
const float PICONSTANT = 3.14159;

float getDepth(vec2 coord);
vec4 getBlurredColor();
vec4 getSample(vec2 coord, vec2 aspectCorrection);
vec4 getSampleWithBoundsCheck(vec2 offset);

float samples = 0.0;
vec2 space;

void main() {
	vec4 baseColor = texture2D(composite, texcoord.st);

	float depth = getDepth(texcoord.st);
	    
	float cursorDepth = getDepth(vec2(0.5, 0.5));
    
    
    if (mixAmount != 0.0) {
		gl_FragColor = mix(baseColor, getBlurredColor(), mixAmount);
   	} else {
   		gl_FragColor = baseColor;
   	}
}






vec4 getSampleWithBoundsCheck(vec2 offset) {
	vec2 coord = texcoord.st + offset;
	if (coord.s <= 1.0 && coord.s >= 0.0 && coord.t <= 1.0 && coord.t >= 0.0) {
		samples += 1.0;
		return texture2D(composite, coord);
	} else {
		return vec4(0.0);
	}
}